@@ -26,7 +26,7 @@ use Web::Scraper;
 use Spreadsheet::XLSX;
 use String::Util qw(trim);
 
-our $VERSION = '1.61'; # VERSION 
+our $VERSION = '1.62'; # VERSION 
 
 our @labels = qw/symbol date isodate close volume high low isin/;
 
@@ -79,7 +79,7 @@ sub load_source {
       $reply = $ua->get($link);
 
       ### Fetched : $link, $reply->code
-      my $xlsx = $reply->content();
+      my $xlsx = $reply->decoded_content();
       my $io;
       open($io, '<', \$xlsx);
 
