@@ -1,5 +1,4 @@
 #!/usr/bin/perl -w
-# vi: set ts=4 sw=4 noai ic showmode showmatch: 
 #    This module is based on the Finance::Quote::BSERO module
 #    It was first called BOMSE but has been renamed to yahooJSON
 #    since it gets a lot of quotes besides Indian
@@ -24,40 +23,31 @@
 
 package Finance::Quote::BorsaItaliana;
 
+require 5.005;
+
 use strict;
 use vars qw($VERSION $YIND_URL_HEAD $YIND_URL_TAIL);
 use LWP::UserAgent;
 use Web::Scraper;
 
-use constant DEBUG => $ENV{DEBUG};
-use if DEBUG, 'Smart::Comments';
-
-our $VERSION = '1.68_01'; # TRIAL VERSION
+our $VERSION = '1.62'; # VERSION
 
 # URL example = https://www.borsaitaliana.it/borsa/search/scheda.html?code=IT0001086567&lang=it
 my $YIND_URL_HEAD = 'https://www.borsaitaliana.it/borsa/search/scheda.html?code=';
 my $YIND_URL_TAIL = '&lang=it';
 
-our $DISPLAY    = 'Borsa Italiana (Bonds), IT';
-our @LABELS = qw/name last date isodate currency method exchange price symbol/;
-our $METHODHASH = {subroutine => \&borsa_italiana,
-                   display => $DISPLAY,
-                   labels => \@LABELS};
-
-sub methodinfo {
-    return (
-        borsa_italiana => $METHODHASH,
+sub methods {
+    return ( borsa_italiana => \&borsa_italiana,
     );
 }
+{
+    my @labels = qw/name last date isodate volume currency method exchange type
+        div_yield eps pe year_range open high low close/;
 
-sub methods {
-	my %m = methodinfo();
-	return map {$_ => $m{$_}{subroutine} } keys %m;
-}
-
-sub labels {
-	my %m = methodinfo();
-	return map {$_ => [@{$m{$_}{labels}}] } keys %m;
+    sub labels {
+        return ( borsa_italiana => \@labels,
+        );
+    }
 }
 
 sub borsa_italiana {
@@ -65,7 +55,6 @@ sub borsa_italiana {
     my $quoter = shift;
     my @bonds = @_;
     my ( %info, $reply, $url, $te, $ts, $row, @cells, $ce );
-	my ($dd,$mm,$yy,$hh,$mi,$ss);
     my ( $my_date );
     my $ua = $quoter->user_agent();
 
@@ -89,8 +78,6 @@ sub borsa_italiana {
 
         if ( $code == 200 ) {
 
-			### [<now>] Body: $body
-
             my $widget = scraper {
                 process 'div.summary-value span.t-text', 'val' => 'TEXT';
             };
@@ -137,11 +124,7 @@ sub borsa_italiana {
             my $date = $result->{dt}[1];
             $date =~ s/.*Contratto:\ //g;
             $date =~ s/[^0123456789]//g;
-            unless ( ($dd,$mm,$yy,$hh,$mi,$ss) = $date =~ /^([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{1,})([0-9]{2})([0-9]{2})\z/ ) {
-                $info{$bond, 'success'} = 0;
-                $info{$bond, 'errormsg'} = 'Invalid trade date. Closed or expired?';
-                next;
-            }
+            my ($dd,$mm,$yy,$hh,$mi,$ss) = $date =~ /^([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{1,})([0-9]{2})([0-9]{2})\z/ or die;
             my $my_date= $dd.".".$mm.".".$yy." ".$hh.":".$mi.":".$ss;
 
             $info{ $bond, "success" }  = 1;
@@ -174,7 +157,7 @@ sub borsa_italiana {
 
 =head1 NAME
 
-Finance::Quote::BorsaItaliana - Obtain bond quotes from Borsa Italiana site
+Finance::Quote::BorsaItaliana - Obtain quotes from Borsa Italiana site
 
 =head1 SYNOPSIS
 
@@ -192,8 +175,7 @@ This module is loaded by default on a Finance::Quote object. It's
 also possible to load it explicitly by placing "BorsaItaliana" in the argument
 list to Finance::Quote->new().
 
-This module provides the "borsa_italiana" fetch method. Currently this
-module retrieves data for bonds only.
+This module provides the "borsa_italiana" fetch method.
 
 =head1 LABELS RETURNED
 
